@@ -1,7 +1,10 @@
+from __future__ import annotations
+
 from datetime import timedelta
-from typing import Any, Dict
+from typing import Any
 
 from airflow import AirflowException
+from airflow.exceptions import AirflowSkipException
 from airflow.providers.amazon.aws.sensors.emr import (
     EmrContainerSensor,
     EmrJobFlowSensor,
@@ -13,6 +16,7 @@ from astronomer.providers.amazon.aws.triggers.emr import (
     EmrJobFlowSensorTrigger,
     EmrStepSensorTrigger,
 )
+from astronomer.providers.utils.sensor_util import poke, raise_error_or_skip_exception
 from astronomer.providers.utils.typing_compat import Context
 
 
@@ -33,19 +37,22 @@ class EmrContainerSensorAsync(EmrContainerSensor):
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure state or success state"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=EmrContainerSensorTrigger(
-                virtual_cluster_id=self.virtual_cluster_id,
-                job_id=self.job_id,
-                max_tries=self.max_retries,
-                aws_conn_id=self.aws_conn_id,
-                poll_interval=self.poll_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=EmrContainerSensorTrigger(
+                    virtual_cluster_id=self.virtual_cluster_id,
+                    job_id=self.job_id,
+                    max_tries=self.max_retries,
+                    aws_conn_id=self.aws_conn_id,
+                    poll_interval=self.poll_interval,
+                ),
+                method_name="execute_complete",
+            )
 
-    def execute_complete(self, context: Context, event: Dict[str, str]) -> None:
+    # Ignoring the override type check because the parent class specifies "context: Any" but specifying it as
+    # "context: Context" is accurate as it's more specific.
+    def execute_complete(self, context: Context, event: dict[str, str]) -> None:  # type: ignore[override]
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -53,7 +60,7 @@ class EmrContainerSensorAsync(EmrContainerSensor):
         """
         if event:
             if event["status"] == "error":
-                raise AirflowException(event["message"])
+                raise_error_or_skip_exception(self.soft_fail, event["message"])
             self.log.info(event["message"])
         return None
 
@@ -79,20 +86,21 @@ class EmrStepSensorAsync(EmrStepSensor):
 
     def execute(self, context: Context) -> None:
         """Deferred and give control to trigger"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=EmrStepSensorTrigger(
-                job_flow_id=self.job_flow_id,
-                step_id=self.step_id,
-                target_states=self.target_states,
-                failed_states=self.failed_states,
-                aws_conn_id=self.aws_conn_id,
-                poke_interval=self.poke_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=EmrStepSensorTrigger(
+                    job_flow_id=self.job_flow_id,
+                    step_id=self.step_id,
+                    target_states=self.target_states,
+                    failed_states=self.failed_states,
+                    aws_conn_id=self.aws_conn_id,
+                    poke_interval=self.poke_interval,
+                ),
+                method_name="execute_complete",
+            )
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> None:  # type: ignore[override]
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -100,8 +108,7 @@ class EmrStepSensorAsync(EmrStepSensor):
         """
         if event:
             if event["status"] == "error":
-                raise AirflowException(event["message"])
-
+                raise_error_or_skip_exception(self.soft_fail, event["message"])
             self.log.info(event.get("message"))
             self.log.info("%s completed successfully.", self.job_flow_id)
 
@@ -133,6 +140,20 @@ class EmrJobFlowSensorAsync(EmrJobFlowSensor):
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure state or success state"""
+        emr_client = self.hook.conn
+        self.log.info("Poking cluster %s", self.job_flow_id)
+        response = emr_client.describe_cluster(ClusterId=self.job_flow_id)
+        state = response["Cluster"]["Status"]["State"]
+        self.log.info("Job flow currently %s", state)
+
+        if state == "TERMINATED":
+            return None
+
+        if state == "TERMINATED_WITH_ERRORS":
+            if self.soft_fail:  # pragma: no cover
+                AirflowSkipException(f"EMR job failed: {self.failure_message_from_response(response)}")
+            raise AirflowException(f"EMR job failed: {self.failure_message_from_response(response)}")
+
         self.defer(
             timeout=timedelta(seconds=self.timeout),
             trigger=EmrJobFlowSensorTrigger(
@@ -145,7 +166,7 @@ class EmrJobFlowSensorAsync(EmrJobFlowSensor):
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Context, event: Dict[str, str]) -> None:
+    def execute_complete(self, context: Context, event: dict[str, str]) -> None:  # type: ignore[override]
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -153,6 +174,6 @@ class EmrJobFlowSensorAsync(EmrJobFlowSensor):
         """
         if event:
             if event["status"] == "error":
-                raise AirflowException(event["message"])
+                raise_error_or_skip_exception(self.soft_fail, event["message"])
             self.log.info(event["message"])
         return None
