@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import asyncio
 from datetime import datetime
-from typing import Any, AsyncIterator, Callable, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, AsyncIterator
 
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 
@@ -18,32 +20,36 @@ class S3KeyTrigger(BaseTrigger):
         url, please leave bucket_name as `None`.
     :param wildcard_match: whether the bucket_key should be interpreted as a
         Unix wildcard pattern
+    :param use_regex: whether to use regex to check bucket
     :param aws_conn_id: reference to the s3 connection
     :param hook_params: params for hook its optional
-    :param check_fn: Function that receives the list of the S3 objects,
-        and returns a boolean
+    :param soft_fail: Set to true to mark the task as SKIPPED on failure
     """
 
     def __init__(
         self,
         bucket_name: str,
-        bucket_key: List[str],
+        bucket_key: list[str],
         wildcard_match: bool = False,
-        check_fn: Optional[Callable[..., bool]] = None,
+        use_regex: bool = False,
         aws_conn_id: str = "aws_default",
         poke_interval: float = 5.0,
+        soft_fail: bool = False,
+        should_check_fn: bool = False,
         **hook_params: Any,
     ):
         super().__init__()
         self.bucket_name = bucket_name
         self.bucket_key = bucket_key
         self.wildcard_match = wildcard_match
-        self.check_fn = check_fn
+        self.use_regex = use_regex
         self.aws_conn_id = aws_conn_id
         self.hook_params = hook_params
         self.poke_interval = poke_interval
+        self.soft_fail = soft_fail
+        self.should_check_fn = should_check_fn
 
-    def serialize(self) -> Tuple[str, Dict[str, Any]]:
+    def serialize(self) -> tuple[str, dict[str, Any]]:
         """Serialize S3KeyTrigger arguments and classpath."""
         return (
             "astronomer.providers.amazon.aws.triggers.s3.S3KeyTrigger",
@@ -51,30 +57,37 @@ class S3KeyTrigger(BaseTrigger):
                 "bucket_name": self.bucket_name,
                 "bucket_key": self.bucket_key,
                 "wildcard_match": self.wildcard_match,
-                "check_fn": self.check_fn,
+                "use_regex": self.use_regex,
                 "aws_conn_id": self.aws_conn_id,
                 "hook_params": self.hook_params,
                 "poke_interval": self.poke_interval,
+                "soft_fail": self.soft_fail,
+                "should_check_fn": self.should_check_fn,
             },
         )
 
-    async def run(self) -> AsyncIterator["TriggerEvent"]:
+    async def run(self) -> AsyncIterator[TriggerEvent]:
         """Make an asynchronous connection using S3HookAsync."""
         try:
             hook = self._get_async_hook()
             async with await hook.get_client_async() as client:
                 while True:
-                    if await hook.check_key(client, self.bucket_name, self.bucket_key, self.wildcard_match):
-                        if self.check_fn is None:
+                    if await hook.check_key(
+                        client, self.bucket_name, self.bucket_key, self.wildcard_match, self.use_regex
+                    ):
+                        if self.should_check_fn:
+                            s3_objects = await hook.get_files(
+                                client, self.bucket_name, self.bucket_key, self.wildcard_match
+                            )
+                            await asyncio.sleep(self.poke_interval)
+                            files = [{"Size": s3_object["Size"]} for s3_object in s3_objects]
+                            yield TriggerEvent({"status": "running", "files": files})
+                        else:
                             yield TriggerEvent({"status": "success"})
-                        s3_objects = await hook.get_files(
-                            client, self.bucket_name, self.bucket_key, self.wildcard_match
-                        )
-                        yield TriggerEvent({"status": "success", "s3_objects": s3_objects})
+                    self.log.info("Sleeping for %s seconds", self.poke_interval)
                     await asyncio.sleep(self.poke_interval)
-
         except Exception as e:
-            yield TriggerEvent({"status": "error", "message": str(e)})
+            yield TriggerEvent({"status": "error", "message": str(e), "soft_fail": self.soft_fail})
 
     def _get_async_hook(self) -> S3HookAsync:
         return S3HookAsync(aws_conn_id=self.aws_conn_id, verify=self.hook_params.get("verify"))
@@ -109,11 +122,11 @@ class S3KeysUnchangedTrigger(BaseTrigger):
         inactivity_period: float = 60 * 60,
         min_objects: int = 1,
         inactivity_seconds: int = 0,
-        previous_objects: Optional[Set[str]] = None,
+        previous_objects: set[str] | None = None,
         allow_delete: bool = True,
         aws_conn_id: str = "aws_default",
-        last_activity_time: Optional[datetime] = None,
-        verify: Optional[Union[bool, str]] = None,
+        last_activity_time: datetime | None = None,
+        verify: bool | str | None = None,
     ):
         super().__init__()
         self.bucket_name = bucket_name
@@ -128,11 +141,11 @@ class S3KeysUnchangedTrigger(BaseTrigger):
         self.inactivity_seconds = inactivity_seconds
         self.allow_delete = allow_delete
         self.aws_conn_id = aws_conn_id
-        self.last_activity_time: Optional[datetime] = last_activity_time
+        self.last_activity_time: datetime | None = last_activity_time
         self.verify = verify
         self.polling_period_seconds = 0
 
-    def serialize(self) -> Tuple[str, Dict[str, Any]]:
+    def serialize(self) -> tuple[str, dict[str, Any]]:
         """Serialize S3KeysUnchangedTrigger arguments and classpath."""
         return (
             "astronomer.providers.amazon.aws.triggers.s3.S3KeysUnchangedTrigger",
@@ -149,7 +162,7 @@ class S3KeysUnchangedTrigger(BaseTrigger):
             },
         )
 
-    async def run(self) -> AsyncIterator["TriggerEvent"]:
+    async def run(self) -> AsyncIterator[TriggerEvent]:
         """Make an asynchronous connection using S3HookAsync."""
         try:
             hook = self._get_async_hook()
