@@ -14,6 +14,8 @@ from airflow.providers.amazon.aws.operators.emr import (
     EmrTerminateJobFlowOperator,
 )
 from airflow.providers.apache.hive.operators.hive import HiveOperator
+from airflow.utils.state import State
+from airflow.utils.trigger_rule import TriggerRule
 from requests import get
 
 from astronomer.providers.apache.hive.sensors.hive_partition import (
@@ -23,6 +25,7 @@ from astronomer.providers.apache.hive.sensors.named_hive_partition import (
     NamedHivePartitionSensorAsync,
 )
 
+HIVE_CLUSTER = os.getenv("HIVE_CLUSTER", "example_hive_sensor_cluster")
 AWS_S3_CREDS = {
     "aws_access_key_id": os.getenv("AWS_ACCESS_KEY_ID", "aws_access_key"),
     "aws_secret_access_key": os.getenv("AWS_SECRET_ACCESS_KEY", "aws_secret_key"),
@@ -50,7 +53,7 @@ main/astronomer/providers/apache/hive/example_dags/zipcodes.csv \
 # If you would like to use a different version of the EMR cluster, then we need to
 # match the hive and hadoop versions same as specified in the integration tests `Dockefile`.
 JOB_FLOW_OVERRIDES = {
-    "Name": "example_hive_sensor_cluster",
+    "Name": HIVE_CLUSTER,
     "ReleaseLabel": "emr-5.34.0",
     "Applications": [
         {"Name": "Spark"},
@@ -78,6 +81,7 @@ JOB_FLOW_OVERRIDES = {
     "Steps": [],
     "JobFlowRole": JOB_FLOW_ROLE,
     "ServiceRole": SERVICE_ROLE,
+    "LogUri": "s3://example_emr_sensor_cluster/",
 }
 
 
@@ -277,6 +281,16 @@ def get_cluster_details(task_instance: Any) -> None:
     )
 
 
+def check_dag_status(**kwargs: Any) -> None:
+    """Raises an exception if any of the DAG's tasks failed and as a result marking the DAG failed."""
+    for task_instance in kwargs["dag_run"].get_task_instances():
+        if (
+            task_instance.current_state() != State.SUCCESS
+            and task_instance.task_id != kwargs["task_instance"].task_id
+        ):
+            raise Exception(f"Task {task_instance.task_id} failed. Failing this DAG run")
+
+
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
     "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
@@ -285,7 +299,7 @@ default_args = {
 
 with DAG(
     dag_id="example_hive_dag",
-    schedule_interval=None,
+    schedule=None,
     start_date=datetime(2021, 1, 1),
     catchup=False,
     default_args=default_args,
@@ -375,6 +389,16 @@ with DAG(
         trigger_rule="all_done",
     )
     # [END howto_operator_emr_terminate_job_flow]
+
+    dag_final_status = PythonOperator(
+        task_id="dag_final_status",
+        provide_context=True,
+        python_callable=check_dag_status,
+        trigger_rule=TriggerRule.ALL_DONE,  # Ensures this task runs even if upstream fails
+        dag=dag,
+        retries=0,
+    )
+
     (
         cluster_creator
         >> describe_created_cluster
@@ -386,4 +410,5 @@ with DAG(
         >> hive_sensor
         >> wait_for_partition
         >> remove_cluster
+        >> dag_final_status
     )
