@@ -1,3 +1,4 @@
+"""Example DAG demonstrating the usage of the KubernetesPodOperatorAsync."""
 import os
 from datetime import datetime, timedelta
 
@@ -20,14 +21,12 @@ else:
 
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
-    "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
-    "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
 with DAG(
     dag_id="example_kubernetes_operator",
     start_date=datetime(2022, 1, 1),
-    schedule_interval=None,
+    schedule=None,
     catchup=False,
     default_args=default_args,
     tags=["example", "async", "k8s"],
@@ -54,6 +53,7 @@ with DAG(
                 'echo \'{"message": "good afternoon!"}\' > /airflow/xcom/return.json'
             ),
         ],
+        do_xcom_push=True,
     )
     # [END howto_operator_kubernetes_pod_async]
 
