@@ -1,12 +1,15 @@
 import os
 import time
 from datetime import timedelta
+from typing import Any
 
 from airflow import DAG
-from airflow.operators.dummy import DummyOperator
+from airflow.operators.empty import EmptyOperator
 from airflow.operators.python import PythonOperator
 from airflow.operators.trigger_dagrun import TriggerDagRunOperator
+from airflow.utils.state import State
 from airflow.utils.timezone import datetime
+from airflow.utils.trigger_rule import TriggerRule
 
 from astronomer.providers.core.sensors.external_task import ExternalTaskSensorAsync
 
@@ -18,15 +21,26 @@ default_args = {
     "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
+
+def check_dag_status(**kwargs: Any) -> None:
+    """Raises an exception if any of the DAG's tasks failed and as a result marking the DAG failed."""
+    for task_instance in kwargs["dag_run"].get_task_instances():
+        if (
+            task_instance.current_state() != State.SUCCESS
+            and task_instance.task_id != kwargs["task_instance"].task_id
+        ):
+            raise Exception(f"Task {task_instance.task_id} failed. Failing this DAG run")
+
+
 with DAG(
     dag_id="example_external_task",
     start_date=datetime(2022, 1, 1),
-    schedule_interval=None,
+    schedule=None,
     catchup=False,
     default_args=default_args,
     tags=["example", "async", "core"],
 ) as dag:
-    start = DummyOperator(task_id="start")
+    start = EmptyOperator(task_id="start")
 
     # [START howto_sensor_external_task_async]
     waiting_for_task = ExternalTaskSensorAsync(
@@ -57,14 +71,20 @@ with DAG(
         trigger_dag_id="example_external_task_async_waits_for_me",
         wait_for_completion=True,
         reset_dag_run=True,
-        allowed_states=["success", "failed", "skipped"],
+        allowed_states=["success", "failed"],
         execution_date="{{execution_date}}",
         poke_interval=1,
     )
 
-    end = DummyOperator(task_id="end")
+    dag_final_status = PythonOperator(
+        task_id="dag_final_status",
+        provide_context=True,
+        python_callable=check_dag_status,
+        trigger_rule=TriggerRule.ALL_DONE,  # Ensures this task runs even if upstream fails
+        retries=0,
+    )
 
-    start >> [waiting_for_task, wait_for_me] >> end
+    start >> [waiting_for_task, wait_for_me] >> dag_final_status
 
-    start >> wait_for_dag >> end
-    start >> wait_to_defer >> external >> end
+    start >> wait_for_dag >> dag_final_status
+    start >> wait_to_defer >> external >> dag_final_status
