@@ -15,7 +15,7 @@ default_args = {
 with DAG(
     dag_id="example_external_task_async_waits_for_me",
     start_date=datetime(2022, 1, 1),
-    schedule_interval=None,
+    schedule=None,
     catchup=False,
     default_args=default_args,
     tags=["example", "async", "core"],
