@@ -6,6 +6,7 @@ from airflow.providers.http.hooks.http import HttpHook
 from airflow.providers.http.sensors.http import HttpSensor
 
 from astronomer.providers.http.triggers.http import HttpTrigger
+from astronomer.providers.utils.sensor_util import poke
 from astronomer.providers.utils.typing_compat import Context
 
 
@@ -68,7 +69,7 @@ class HttpSensorAsync(HttpSensor):
     ) -> None:
         self.endpoint = endpoint
         # TODO: Remove once deprecated
-        if poll_interval:
+        if kwargs.get("poke_interval") is None:
             self.poke_interval = poll_interval
             warnings.warn(
                 "Argument `poll_interval` is deprecated and will be removed "
@@ -103,12 +104,13 @@ class HttpSensorAsync(HttpSensor):
         if self.response_check:
             self.log.warning("Since response_check param is passed, using the sync version of the sensor.")
             super().execute(context=context)
-        else:
+        elif not poke(self, context):
             self.defer(
                 timeout=timedelta(seconds=self.timeout),
                 trigger=HttpTrigger(
-                    method=self.hook.method,  # TODO: Fix this to directly get method from ctor
                     endpoint=self.endpoint,
+                    http_conn_id=self.http_conn_id,
+                    method=self.hook.method,  # TODO: Fix this to directly get method from ctor
                     data=self.request_params,
                     headers=self.headers,
                     extra_options=self.extra_options,
