@@ -1,18 +1,26 @@
 from __future__ import annotations
 
+import logging
 import typing
+from contextlib import closing
 from datetime import timedelta
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, List
 
+import requests
 from airflow.exceptions import AirflowException
 
+from snowflake.connector import SnowflakeConnection
+from snowflake.connector.constants import QueryStatus
+
 try:
     from airflow.providers.snowflake.operators.snowflake import SnowflakeOperator
 except ImportError:  # pragma: no cover
     # For apache-airflow-providers-snowflake > 3.3.0
     # currently added type: ignore[no-redef, attr-defined] and pragma: no cover because this import
     # path won't be available in current setup
-    from airflow.providers.common.sql.operators.sql import SQLExecuteQueryOperator as SnowflakeOperator  # type: ignore[assignment] # noqa: E501 # pragma: no cover
+    from airflow.providers.common.sql.operators.sql import (  # type: ignore[assignment]
+        SQLExecuteQueryOperator as SnowflakeOperator,
+    )
 
 from astronomer.providers.snowflake.hooks.snowflake import (
     SnowflakeHookAsync,
@@ -29,6 +37,18 @@ from astronomer.providers.snowflake.triggers.snowflake_trigger import (
 from astronomer.providers.utils.typing_compat import Context
 
 
+def _check_queries_finish(conn: SnowflakeConnection, query_ids: list[str]) -> bool:
+    """Check whether snowflake queries finish (in aborting, failed_with_error or success)"""
+    with closing(conn) as conn:
+        for query_id in query_ids:
+            status = conn.get_query_status_throw_if_error(query_id)
+            if status == QueryStatus.SUCCESS:
+                continue
+            elif conn.is_still_running(status):
+                return False
+    return True
+
+
 class SnowflakeOperatorAsync(SnowflakeOperator):
     """
     - SnowflakeOperatorAsync uses the snowflake python connector ``execute_async`` method to submit a database command
@@ -91,12 +111,12 @@ class SnowflakeOperatorAsync(SnowflakeOperator):
         self,
         *,
         snowflake_conn_id: str = "snowflake_default",
-        warehouse: Optional[str] = None,
-        database: Optional[str] = None,
-        role: Optional[str] = None,
-        schema: Optional[str] = None,
-        authenticator: Optional[str] = None,
-        session_parameters: Optional[Dict[str, Any]] = None,
+        warehouse: str | None = None,
+        database: str | None = None,
+        role: str | None = None,
+        schema: str | None = None,
+        authenticator: str | None = None,
+        session_parameters: dict[str, Any] | None = None,
         poll_interval: int = 5,
         handler: Callable[[Any], Any] = fetch_all_snowflake_handler,
         return_last: bool = True,
@@ -167,20 +187,22 @@ class SnowflakeOperatorAsync(SnowflakeOperator):
         if self.do_xcom_push:
             context["ti"].xcom_push(key="query_ids", value=self.query_ids)
 
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=SnowflakeTrigger(
-                task_id=self.task_id,
-                poll_interval=self.poll_interval,
-                query_ids=self.query_ids,
-                snowflake_conn_id=self.snowflake_conn_id,
-            ),
-            method_name="execute_complete",
-        )
+        if not _check_queries_finish(hook.get_conn(), self.query_ids):
+            logging.info("Task deferred")
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=SnowflakeTrigger(
+                    task_id=self.task_id,
+                    poll_interval=self.poll_interval,
+                    query_ids=self.query_ids,
+                    snowflake_conn_id=self.snowflake_conn_id,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            logging.info("Queries finish before deferred")
 
-    def execute_complete(
-        self, context: Context, event: Optional[Dict[str, Union[str, List[str]]]] = None
-    ) -> Any:
+    def execute_complete(self, context: Context, event: dict[str, str | list[str]] | None = None) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -189,7 +211,7 @@ class SnowflakeOperatorAsync(SnowflakeOperator):
         self.log.info("SQL in execute_complete: %s", self.sql)
         if event:
             if "status" in event and event["status"] == "error":
-                msg = "{0}: {1}".format(event["type"], event["message"])
+                msg = f"sfquid: {event['query_id']}, {event['type']}: {event['message']}"
                 raise AirflowException(msg)
             elif "status" in event and event["status"] == "success":
                 hook = self.get_db_hook()
@@ -271,17 +293,17 @@ class SnowflakeSqlApiOperatorAsync(SnowflakeOperator):
         self,
         *,
         snowflake_conn_id: str = "snowflake_default",
-        warehouse: Optional[str] = None,
-        database: Optional[str] = None,
-        role: Optional[str] = None,
-        schema: Optional[str] = None,
-        authenticator: Optional[str] = None,
-        session_parameters: Optional[Dict[str, Any]] = None,
+        warehouse: str | None = None,
+        database: str | None = None,
+        role: str | None = None,
+        schema: str | None = None,
+        authenticator: str | None = None,
+        session_parameters: dict[str, Any] | None = None,
         poll_interval: int = 5,
         statement_count: int = 0,
         token_life_time: timedelta = LIFETIME,
         token_renewal_delta: timedelta = RENEWAL_DELTA,
-        bindings: Optional[Dict[str, Any]] = None,
+        bindings: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         self.warehouse = warehouse
@@ -337,6 +359,25 @@ class SnowflakeSqlApiOperatorAsync(SnowflakeOperator):
         if self.do_xcom_push:
             context["ti"].xcom_push(key="query_ids", value=self.query_ids)
 
+        succeeded_query_ids = []
+        for query_id in self.query_ids:
+            self.log.info("Retrieving status for query id %s", query_id)
+            header, params, url = hook.get_request_url_header_params(query_id)
+            with requests.session() as session:
+                session.headers = header
+                with session.get(url, params=params) as resp:
+                    event = hook.process_query_status_response(resp.json(), resp.status_code)
+                    if resp.status_code == 202:
+                        break
+                    elif resp.status_code == 200:
+                        succeeded_query_ids.append(query_id)
+                    else:
+                        raise AirflowException(f"{event['status']}: {event['message']}")
+
+        if len(self.query_ids) == len(succeeded_query_ids):
+            self.log.info("%s completed successfully.", self.task_id)
+            return
+
         self.defer(
             timeout=self.execution_timeout,
             trigger=SnowflakeSqlApiTrigger(
@@ -349,9 +390,7 @@ class SnowflakeSqlApiOperatorAsync(SnowflakeOperator):
             method_name="execute_complete",
         )
 
-    def execute_complete(
-        self, context: Context, event: Optional[Dict[str, Union[str, List[str]]]] = None
-    ) -> None:
+    def execute_complete(self, context: Context, event: dict[str, str | list[str]] | None = None) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -359,8 +398,7 @@ class SnowflakeSqlApiOperatorAsync(SnowflakeOperator):
         """
         if event:
             if "status" in event and event["status"] == "error":
-                msg = "{0}: {1}".format(event["status"], event["message"])
-                raise AirflowException(msg)
+                raise AirflowException(f"{event['status']}: {event['message']}")
             elif "status" in event and event["status"] == "success":
                 hook = SnowflakeSqlApiHookAsync(snowflake_conn_id=self.snowflake_conn_id)
                 query_ids = typing.cast(List[str], event["statement_query_ids"])
